SymPy Papers
------------

A list of papers which either use or mention SymPy, as well as presentations
given about SymPy at conferences can be seen at `SymPy Papers
<https://github.com/sympy/sympy/wiki/SymPy-Papers>`_.

Planet SymPy
------------

We have a blog aggregator at http://planet.sympy.org.

SymPy logos
-----------

SymPy has a collection of official logos, which can
be generated from
`sympy.svg <https://github.com/sympy/sympy/blob/master/doc/src/logo/sympy.svg>`_
in your local copy of SymPy by::

    $ cd doc
    $ make logo # will be stored in the _build/logo subdirectory

The license of all the logos is the same as SymPy: BSD. See the LICENSE file in
the trunk for more information.

.. _mailinglist:        https://groups.google.com/forum/#!forum/sympy

Blogs, News, Magazines
----------------------

You can see a list of blogs/news/magazines mentioning SymPy (that we know of) on
our `wiki page <https://github.com/sympy/sympy/wiki/SymPy-in-the-news>`_.
